@@ -4,18 +4,19 @@ import (
 	"errors"
 	"fmt"
 	"os"
+	"slices"
 	"strings"
 
+	"github.com/charmbracelet/bubbles/help"
 	"github.com/charmbracelet/bubbles/textinput"
 	"github.com/charmbracelet/bubbles/viewport"
 	tea "github.com/charmbracelet/bubbletea"
-	"github.com/charmbracelet/x/ansi"
-	"github.com/charmbracelet/x/term"
-	"github.com/sahilm/fuzzy"
-
-	"github.com/charmbracelet/gum/internal/exit"
 	"github.com/charmbracelet/gum/internal/files"
 	"github.com/charmbracelet/gum/internal/stdin"
+	"github.com/charmbracelet/gum/internal/timeout"
+	"github.com/charmbracelet/gum/internal/tty"
+	"github.com/charmbracelet/x/ansi"
+	"github.com/sahilm/fuzzy"
 )
 
 // Run provides a shell script interface for filtering through options, powered
@@ -33,8 +34,8 @@ func (o Options) Run() error {
 	v := viewport.New(o.Width, o.Height)
 
 	if len(o.Options) == 0 {
-		if input, _ := stdin.Read(); input != "" {
-			o.Options = strings.Split(input, "\n")
+		if input, _ := stdin.Read(stdin.StripANSI(o.StripANSI)); input != "" {
+			o.Options = strings.Split(input, o.InputDelimiter)
 		} else {
 			o.Options = files.List()
 		}
@@ -44,12 +45,14 @@ func (o Options) Run() error {
 		return errors.New("no options provided, see `gum filter --help`")
 	}
 
-	if o.SelectIfOne && len(o.Options) == 1 {
-		fmt.Println(o.Options[0])
-		return nil
-	}
+	ctx, cancel := timeout.Context(o.Timeout)
+	defer cancel()
 
-	options := []tea.ProgramOption{tea.WithOutput(os.Stderr)}
+	options := []tea.ProgramOption{
+		tea.WithOutput(os.Stderr),
+		tea.WithReportFocus(),
+		tea.WithContext(ctx),
+	}
 	if o.Height == 0 {
 		options = append(options, tea.WithAltScreen())
 	}
@@ -58,21 +61,43 @@ func (o Options) Run() error {
 	if o.Value != "" {
 		i.SetValue(o.Value)
 	}
+
+	choices := map[string]string{}
+	filteringChoices := []string{}
+	for _, opt := range o.Options {
+		s := ansi.Strip(opt)
+		choices[s] = opt
+		filteringChoices = append(filteringChoices, s)
+	}
 	switch {
 	case o.Value != "" && o.Fuzzy:
-		matches = fuzzy.Find(o.Value, o.Options)
+		matches = fuzzy.Find(o.Value, filteringChoices)
 	case o.Value != "" && !o.Fuzzy:
-		matches = exactMatches(o.Value, o.Options)
+		matches = exactMatches(o.Value, filteringChoices)
 	default:
-		matches = matchAll(o.Options)
+		matches = matchAll(filteringChoices)
 	}
 
 	if o.NoLimit {
 		o.Limit = len(o.Options)
 	}
 
-	p := tea.NewProgram(model{
-		choices:               o.Options,
+	if o.SelectIfOne && len(matches) == 1 {
+		tty.Println(matches[0].Str)
+		return nil
+	}
+
+	km := defaultKeymap()
+	if o.NoLimit || o.Limit > 1 {
+		km.Toggle.SetEnabled(true)
+		km.ToggleAndPrevious.SetEnabled(true)
+		km.ToggleAndNext.SetEnabled(true)
+		km.ToggleAll.SetEnabled(true)
+	}
+
+	m := model{
+		choices:               choices,
+		filteringChoices:      filteringChoices,
 		indicator:             o.Indicator,
 		matches:               matches,
 		header:                o.Header,
@@ -92,47 +117,56 @@ func (o Options) Run() error {
 		limit:                 o.Limit,
 		reverse:               o.Reverse,
 		fuzzy:                 o.Fuzzy,
-		timeout:               o.Timeout,
-		hasTimeout:            o.Timeout > 0,
-		sort:                  o.Sort,
-	}, options...)
+		sort:                  o.Sort && o.FuzzySort,
+		strict:                o.Strict,
+		showHelp:              o.ShowHelp,
+		keymap:                km,
+		help:                  help.New(),
+	}
 
-	tm, err := p.Run()
+	isSelectAll := len(o.Selected) == 1 && o.Selected[0] == "*"
+	currentSelected := 0
+	if len(o.Selected) > 0 {
+		for i, option := range matches {
+			if currentSelected >= o.Limit || (!isSelectAll && !slices.Contains(o.Selected, option.Str)) {
+				continue
+			}
+			if o.Limit == 1 {
+				m.cursor = i
+				m.selected[option.Str] = struct{}{}
+			} else {
+				currentSelected++
+				m.selected[option.Str] = struct{}{}
+			}
+		}
+	}
+
+	tm, err := tea.NewProgram(m, options...).Run()
 	if err != nil {
 		return fmt.Errorf("unable to run filter: %w", err)
 	}
-	m := tm.(model)
-	if m.aborted {
-		return exit.ErrAborted
-	}
 
-	isTTY := term.IsTerminal(os.Stdout.Fd())
+	m = tm.(model)
+	if !m.submitted {
+		return errors.New("nothing selected")
+	}
 
 	// allSelections contains values only if limit is greater
 	// than 1 or if flag --no-limit is passed, hence there is
 	// no need to further checks
 	if len(m.selected) > 0 {
-		o.checkSelected(m, isTTY)
+		o.checkSelected(m)
 	} else if len(m.matches) > m.cursor && m.cursor >= 0 {
-		if isTTY {
-			fmt.Println(m.matches[m.cursor].Str)
-		} else {
-			fmt.Println(ansi.Strip(m.matches[m.cursor].Str))
-		}
+		tty.Println(m.matches[m.cursor].Str)
 	}
 
-	if !o.Strict && len(m.textinput.Value()) != 0 && len(m.matches) == 0 {
-		fmt.Println(m.textinput.Value())
-	}
 	return nil
 }
 
-func (o Options) checkSelected(m model, isTTY bool) {
+func (o Options) checkSelected(m model) {
+	out := []string{}
 	for k := range m.selected {
-		if isTTY {
-			fmt.Println(k)
-		} else {
-			fmt.Println(ansi.Strip(k))
-		}
+		out = append(out, k)
 	}
+	tty.Println(strings.Join(out, o.OutputDelimiter))
 }
