@@ -2,8 +2,10 @@ package style
 
 // Options is the customization options for the style command.
 type Options struct {
-	Text  []string        `arg:"" optional:"" help:"Text to which to apply the style"`
-	Style StylesNotHidden `embed:""`
+	Text      []string        `arg:"" optional:"" help:"Text to which to apply the style"`
+	Trim      bool            `help:"Trim whitespaces on every input line" default:"false"`
+	StripANSI bool            `help:"Strip ANSI sequences when reading from STDIN" default:"true" negatable:"" env:"GUM_STYLE_STRIP_ANSI"`
+	Style     StylesNotHidden `embed:""`
 }
 
 // Styles is a flag set of possible styles.
